@@ -101,6 +101,7 @@ static gchar *contributors[] = {
 	"Christopher R. Gabriel",
 	"Mark Galassi",
 	"Tony Gale",
+	"Matthew Garrett",
 	"Carlos Garnacho Parro",
 	"Jeff Garzik",
 	N_("The Mysterious GEGL"),
@@ -177,6 +178,7 @@ static gchar *contributors[] = {
 	"Nick Lopez",
 	"Dirk Lutjens",
 	"Josh MacDonald",
+	"Davyd Madeley",
 	"Paolo Maggi",
 	"Sam Magnuson",
 	"Ian Main",
@@ -333,9 +335,7 @@ static gchar *contributors[] = {
 	"Orest Zborowski",
 	"Sascha Ziemann",
 	"Michael Zucchi",
-	"Jason van Zyl",
-	"",
-	""
+	"Jason van Zyl"
 };
 
 
