@@ -56,6 +56,7 @@ static char             **introduction_messages = NULL;
 static GnomeCanvasItem   *subheader = NULL;
 static gdouble            version_info_height = 0.0;
 static gint               contrib_i = 0;
+static gint              *contrib_order;
 
 /* funky animations */
 typedef struct {
@@ -134,10 +135,11 @@ canvas_button_press_event (GtkWidget      *widget,
 	if (event->y <= 80.0)
 		return FALSE;
 
-	if (!contributors[contrib_i])
+	if (contrib_i >= (G_N_ELEMENTS (contributors) - 1))
 		text = g_strdup_printf ("<b>%s</b>", _("The End!"));
 	else {
-		text = g_strdup_printf ("<b>%s</b>", contributors[contrib_i]);
+		text = g_strdup_printf ("<b>%s</b>", 
+					contributors[contrib_order[contrib_i]]);
 		contrib_i++;
 	}
 
@@ -159,7 +161,7 @@ display_contributors (gpointer data)
 	static GnomeCanvasItem *contributor_rect = NULL;
 	static GnomeCanvasItem *contributor_text = NULL;
 
-	if (!contributors[contrib_i]) {
+	if (contrib_i >= (G_N_ELEMENTS (contributors) - 1)) {
 		g_signal_handlers_disconnect_by_func (canvas,
 						      canvas_button_press_event,
 						      contributor_text);
@@ -180,7 +182,8 @@ display_contributors (gpointer data)
 					       "fill_color", "White",
 					       NULL);
 
-		text = g_strdup_printf ("<b>%s</b>", contributors[contrib_i]);
+		text = g_strdup_printf ("<b>%s</b>", 
+					contributors[contrib_order[contrib_i]]);
 		contributor_text =
 			gnome_canvas_item_new (GNOME_CANVAS_GROUP (contributor),
 					       gnome_canvas_text_get_type (),
@@ -200,7 +203,8 @@ display_contributors (gpointer data)
 	} else {
 		gchar *text;
 
-		text = g_strdup_printf ("<b>%s</b>", contributors[contrib_i]);
+		text = g_strdup_printf ("<b>%s</b>", 
+					contributors[contrib_order[contrib_i]]);
 		gnome_canvas_item_set (contributor_text,
 				       "markup", text,
 				       "fill_color_rgba", 0xffffffff,
@@ -659,6 +663,9 @@ strip_newlines (const char *str)
  * around is required (in particular, we cannot quit after finding the first
  * match).
  */
+
+/* FIXME: this code is atrocious */
+
 static void
 get_description_messages (xmlNodePtr node)
 {
@@ -711,6 +718,7 @@ get_description_messages (xmlNodePtr node)
 									cur)) {
 							xmlFree (best);
 							best = xmlStrdup (cur);
+							g_free (best_value);
 							best_value = g_strdup (tmp);
 							/* If this is the first
 							 * language on the
@@ -745,24 +753,31 @@ get_description_messages (xmlNodePtr node)
 
 	introduction_messages[i] = NULL;
 
-	g_free (best_value);
 	g_slist_free (list);
 }
 
 static char*
 create_date_string (const char *value)
 {
-	struct tm tm;
-	char *result;
-	GDate *date = g_date_new ();
+	char  *result;
+	GDate *date;
+	int    day;
+	int    month;
+	int    year;
 
-	if (!strptime (value, "%Y-%m-%d", &tm)) {
+	/* YYYY-MM-DD */
+	if (sscanf (value, "%d-%d-%d", &year, &month, &day) < 3)
 		return NULL;
-	}
-	g_date_set_dmy (date, tm.tm_mday, 1 + tm.tm_mon, 1900 + tm.tm_year);
+
+	date = g_date_new ();
+
+	g_date_set_dmy (date, day, month, year);
+
 	result = g_new0 (char, 20);
 	g_date_strftime (result, 20, "%x", date);
+
 	g_date_free (date);
+
 	return result;
 }
 
@@ -1161,6 +1176,37 @@ create_about_dialog (void)
 	return dialog;
 }
 
+static void
+generate_randomness ()
+{
+	gint i;
+	gint random_number;
+	gint tmp;
+	gint num_contributors;
+	GRand *generator;
+
+	generator = g_rand_new ();
+
+	num_contributors = G_N_ELEMENTS (contributors);
+
+	contrib_order = g_malloc (num_contributors * sizeof (gint));
+
+	for (i = 0; i < num_contributors; i++) {
+		contrib_order[i]=i;
+	}
+
+	for (i = 0; i < num_contributors; i++) {
+		random_number = g_rand_int_range (generator, i, 
+						  num_contributors);
+		tmp = contrib_order[i];
+		contrib_order[i] = contrib_order[random_number];
+		contrib_order[random_number] = tmp;
+	}
+
+	g_rand_free (generator);
+}
+		
+
 /* main */
 int
 main (int argc, char **argv)
@@ -1181,6 +1227,8 @@ main (int argc, char **argv)
 	if (!dialog)
 		return -1;
 
+	generate_randomness ();
+
 	gtk_widget_show_all (dialog);
 
 	gtk_main ();
